A S4 class for a SNP matrix. Storing SNP information using a
byte-level (raw) storage scheme jointly with positions.
ibdDataA matrix of IBD-block stored in type 'raw'.
indivNamesA vector of individual names.
lociNamesA vector of loci names.
alleleLabelsA vector of the block-allele label names.
positionA matrix with three rows. The first row contains the chromosomes, the second row contains the start positions of a block, and the third row contains the end population of a block.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.